summary.fitEmaxB: Print a summary of the fitted Bayesian Emax model

summary.fitEmaxBR Documentation

Print a summary of the fitted Bayesian Emax model

Description

Print a summary of the fitted Bayesian Emax model

Usage

## S3 method for class 'fitEmaxB'
summary(object, ...)

Arguments

object

Object output by fitEmaxB

...

No options implemented.


clinDR documentation built on Sept. 21, 2026, 9:07 a.m.