| printemaxPrior | R Documentation |
Creates a templated description of the prior distribution for the parameters of the Emax model suitable for inclusion in a study protocol or statistical analysis plan (SAP). The function outputs the text to a word file stored by default in the current working directory. The level of detail is tailored to protocol or SAP requirements.
## S3 method for class 'emaxPrior'
print(x, doc=FALSE, diffuse=c(pbo=TRUE,eff=TRUE),
file=paste('emaxPrior',format(Sys.time(),
"%b%d%H%M%S"),'.docx',sep=''),
modType=c('4','3'), docType=c('sap','protocol'),
font.family = "Courier New", rounding=3, ...)
x |
Object created by function |
doc |
When |
diffuse |
When |
file |
Filename to be stored in output location. If a custom filename is specified it must include the ".docx" extension. |
modType |
Character value ('4' or '3') that determines whether the 4-parameter sigmoidal Emax paramter is included, or the 3-parameter hyperbolic model is assumed with the Hill (slope) parameter set to 1 |
docType |
When |
font.family |
The default 'Courier New' font family should be used and changed only if it is not available. |
rounding |
Number of decimal places reported for numerical values. |
... |
No other inputs are supported. |
If the emaxPrior object is entered at the command line, the implied print
function is called without the required diffuse flag. The
object will be printed as a list without any generated text.
To generate a protocol/sap text, the doc must be TRUE and
the diffuse variable must be set (TRUE/FALSE).
A Microsoft .docx file that can be edited for inclusion in
a protocol/sap is written to the location specified by file. An
invisible text version of the output is also returned. If the output
of print.emaxPrior is assigned, the text may then be printed
from the saved output using the function cat.
Budhaditya Goswami, Neal Thomas
emaxPrior.control
prior<-emaxPrior.control(epmu=0,epsca=4,difTargetmu=0,
difTargetsca=4,dTarget=20,
p50=(2+5)/2,
sigmalow=0.01,sigmaup=3)
print(prior,doc=TRUE,diffuse=c(TRUE,TRUE),file=NULL)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.